===============
django Organice
===============

All-in-one collaboration solution.  For non-profit organizations, sports clubs, small to medium-sized businesses.
Nice, very nice, http://organice.io

django Organice is a nice way to run a collaboration platform, an intranet, and websites for your business.
It's a compilation of the best Django packages, preconfigured for getting you started quickly.  Being powered by
the well-known `Django Web framework`_ it's a safe choice for your IT investment providing an easily extensible
architecture.

Primary goal of the software is to provide an absolutely intuitive, consistent user experience.  Because in fast-paced,
flexible, probably small-margin businesses you don't have the time to invest in training your staff.  We build on
promising, reliable Django components, and rather invest in those projects than build source code here.  We expect to
continually tune the compilation to keep the source footprint small, keeping the project lean and responsive.

See http://organice.io for more information.

Features
========

Major components of django Organice are:

- Django Web framework
- full-featured content management (django CMS)
- full-featured versatile blog (Zinnia, cmsplugin)
- events with event calendar (via Zinnia)
- flexible contact pages (cmsplugin)
- link collection pages
- full-featured newsletter (Emencia)
- user profiles (userena)
- multi-language support
- multiple websites support
- database support for PostgreSQL, MySQL, and more

Features on the roadmap include:

- social login (Python Social Auth)
- group spaces with automatic mailing list (group_name@yoursite.tld)
- issue list / task management
- documentation area / wiki (probably by use of CMS functionality)
- discussion forum / Q&A board (Askbot, Misago)
- content download for magazine generation
- unobtrusive, integrated, transparent document and asset management
- DropBox, OneDrive, Google Drive, iCloud, etc. integration
- fully integrated search (Haystack)
- web analytics respecting your privacy (Piwik)
- live chat or chat integration

Who is using django Organice?
=============================

Examples of websites running django Organice:

- `Kreuzlingen Rudolf Steiner school`_

Download and Contributions
==========================

Official repositories: (kept in sync)

1. Bitbucket: https://bitbucket.org/bittner/django-organice
#. GitHub: https://github.com/bittner/django-organice

Getting Help
============

- Documentation is available at http://docs.organice.io
- Questions? Please use StackOverflow_. Tag your questions with ``django-organice``.
- Found a bug? Please use either the Bitbucket_ or GitHub_ issue tracker (you choose)


.. _`Django Web framework`: https://www.djangoproject.com/
.. _`Kreuzlingen Rudolf Steiner school`: http://www.rssk.ch/
.. _StackOverflow: http://stackoverflow.com/questions/tagged/django-organice
.. _Bitbucket: https://bitbucket.org/bittner/django-organice/issues
.. _GitHub: https://github.com/bittner/django-organice/issues
